@@ -60,7 +60,10 @@ class Publisher:
         return self._publish_stream
 
     async def publish(self, message: dict):
-        self.publish_stream.put_nowait(message)
+        try:
+            await self.publish_stream.put(message)
+        except Exception as e:
+            self.logger().error(f"An error occurred while publishing {e}")
 
     async def start(self):
         self._redis = await create_redis((self._url, self._port), db=self._db, password=self._password, ssl=self._ssl)
