@@ -4,6 +4,7 @@ from asyncio import Task
 from typing import Optional, Any
 
 import aioredis
+from aioredis import create_redis
 
 from komolibs.core.utils.async_utils import safe_ensure_future
 from komolibs.logger import KomoLogger
@@ -16,9 +17,16 @@ class Subscriber:
     _shared_instance: "Subscriber" = None
 
     @classmethod
-    def get_instance(cls, url: str, channel: str, output: asyncio.Queue) -> "Subscriber":
+    def get_instance(cls,
+                     url: str,
+                     port: int,
+                     password: str,
+                     db: int = 0,
+                     ssl: bool = True,
+                     channel: Optional[str] = "*",
+                     output: asyncio.Queue = asyncio.Queue()) -> "Subscriber":
         if cls._shared_instance is None:
-            cls._shared_instance = Subscriber(url=url, channel=channel, stream_output=output)
+            cls._shared_instance = Subscriber(url=url, port=port, password=password, db=db, ssl=ssl, channel=channel, output=output)
         return cls._shared_instance
 
     @classmethod
@@ -27,17 +35,26 @@ class Subscriber:
             cls.subscriber_logger = logging.getLogger(__name__)
         return cls.subscriber_logger
 
-    def __init__(self, url: str,
+    def __init__(self,
+                 url: str,
+                 port: int,
+                 password: str,
+                 db: int = 0,
+                 ssl: bool = True,
                  channel: Optional[str] = "*",
-                 stream_output: asyncio.Queue = asyncio.Queue()):
-        self._url = url
+                 output: asyncio.Queue = asyncio.Queue()):
+        self._url: str = url
+        self._port = port
+        self._password = password
+        self._db = db
+        self._ssl = ssl
         self._channel: Optional[str] = channel
         self._redis: Optional[Any] = None
         self._pubsub: Optional[Any] = None
         self._ready: bool = False
 
         self._subscribe_task: Optional[Task] = None
-        self._message_stream: asyncio.Queue = stream_output
+        self._message_stream: asyncio.Queue = output
 
     @property
     def ready(self):
@@ -45,7 +62,7 @@ class Subscriber:
 
     async def start(self):
         try:
-            self._redis = await aioredis.create_redis(self._url)
+            self._redis = await create_redis((self._url, self._port), db=self._db, password=self._password, ssl=self._ssl)
             res = await self._redis.subscribe(self._channel)
             self._pubsub = res[0]
 
